package java.de.TimeSlice;

/**
 * @author      Burghard Grueter
 * @author      Johannes Schick
 * @version     1.0, 11/06/2000
 * @since       JDK1.2
 */
	/**
	 * interface <pre>ControlpanelListener</pre>
	 * is a collection of messages send by instances
	 * of <pre>Controlpanel</pre> or their child windows
	 * (<pre>Taskpanel</pre> its implemented by <pre>TaskManager</pre>
	 */
public interface ControlPanelListener
{

	/**
	 * add the <pre>Task t</pre> to the TaskManager (being the listener)
	 *
	 * @param   t  
	 *				the new Task to add to the TaskManager
	 
	 * @exception   TaskNameAlreadyExist  
	 */
	public void addTask (Task t) throws TaskNameAlreadyExist;

	/**
	 * removes the <pre>Task</pre> named <pre>TaskName</pre>
	 * from the TaskManager. Is called from <pre>TaskPanel<pre>,
	 * when it is closed
	 *
	 * @param   TaskName  
	 */
	public void deleteTask (String TaskName);

	/**
	 * called by the <pre>TaskPanel</pre> associated to the edited data
	 *
	 * @param   OldName  : name of the <pre>Task</pre> before editing
	 * @param   t  		 : contains the new data	
	 * @exception   TaskNameAlreadyExist  
	 */
	public void editTask (String OldName, Task t) throws TaskNameAlreadyExist;							;

	/**
	 * activates an existing Task
	 *
	 * @param   active   whether active or not
	 * @param   TaskName  
	 */
	public void activateTask (boolean active, String TaskName);
}

