package java.de.TimeSlice;
	 
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;


/**
 * @author      Burghard Grueter
 * @author      Johannes Schick
 * @version     1.0, 11/06/2000
 * @since       JDK1.2
 */
	/**
	 * class <pre>TaskDialog</pre> gets data from user input 
	 * for the Tasks managed by <pre>TimeSlice</pre>
	 * it is called to add and to edit a Task
	 */
public class TaskDialog extends JDialog implements ActionListener {

    public TaskDialog(JFrame parent, String title, String prompt) {

	    super(parent, title, true);
		
		buildGUI();
				
    }
	
	public void cleanFields() 
	{
		setFields("","","");
	}
	

	/**
	 * presets the three data inputs that can be manipulated in this
	 * Dialog with the given values 
	 *
	 * @param   TaskName  
	 * @param   Dauer  
	 * @param   Periode  
	 */
	public void setFields(String TaskName, String Dauer, String Periode)
	{
		jtfTaskName.setText(TaskName);
		jtfDauer.setText(Dauer);
		jtfPeriode.setText(Periode);
	}	


	/**
	 * depending on the pushed button  the <pre>modalresult</pre>
	 * is set, but the window is hidden anyway.
	 * 
	 * @param   e  
	 */
  	public void actionPerformed(ActionEvent e) 
    {	  	
	  if (e.getSource()==jbOk)
	    modalResult = MR_OK;
	  else
	    modalResult = MR_CANCEL; 
	  
	  hide();  
	   	
    }
	

	/**
	 * this method is called by the owning classes to add and to edit
	 * tasks. the fields are preset with the given parameters
	 *
	 * @param   TaskName  
	 * @param   Dauer  
	 * @param   Periode  
	 * @return   generated <pre>Task</pre> instance out of the data from 
	 			 user input
	 * @exception   NumberFormatException  
	 */
	public Task getTaskData(String TaskName, String Dauer, String Periode) throws NumberFormatException 
	{ 
		setFields(TaskName, Dauer, Periode);
		
	 	show();
		
		if (modalResult == MR_OK)
		{
		   
			Task h =  new Task(jtfTaskName.getText(),
								Long.parseLong(jtfDauer.getText())*TaskTimer.HOUR,
			                  	Long.parseLong(jtfPeriode.getText())*TaskTimer.DAY);		
								
			return h;		
		}		
 	    else
		  return null;
	}  
	  
	  

    final int MR_OK = 0;
	final int MR_CANCEL = 1; 

	int modalResult;  
		
    JButton jbOk;
    JButton jbCancel;
	
    JTextField jtfTaskName;
    JTextField jtfDauer;
    JTextField jtfPeriode;
    

	/**
	 * adds two components of one row into a GridBagLayout
	 *
	 * @param   comp1  
	 * @param   comp2  
	 * @param   anchor  
	 */
	private void addInputLine(JComponent comp1, JComponent comp2, int anchor)
	{
		GridBagConstraints c = new GridBagConstraints();
		c.anchor = anchor;
		
		c.insets = new Insets(4,4,4,4);
		
		JPanel pane = (JPanel) getContentPane();
		GridBagLayout gridbag = (GridBagLayout) pane.getLayout();
		
		gridbag.setConstraints(comp1, c);
		pane.add(comp1);
		
		c.gridwidth = GridBagConstraints.REMAINDER;
		gridbag.setConstraints(comp2, c);
		pane.add(comp2);
	}
	
	// boring GUI constuction
	private void buildGUI()
	{	    
	    
		JPanel pane = new JPanel();
		
		GridBagLayout gridbag = new GridBagLayout();
		
        pane.setLayout(gridbag);
						
		setContentPane(pane);
        
		jtfTaskName =new JTextField(10);			
		addInputLine(new JLabel("TaskName"), jtfTaskName, GridBagConstraints.WEST);

        jtfDauer =new JTextField(3);				
		addInputLine(new JLabel("Dauer (Stunden)"), jtfDauer, GridBagConstraints.WEST);
		
		jtfPeriode=new JTextField(3);
		addInputLine(new JLabel("Periode (Tage)"), jtfPeriode, GridBagConstraints.WEST);
		
        jbOk=new JButton("Ok");
		jbOk.addActionListener(this);
		
        jbCancel=new JButton("Abbrechen");
		jbCancel.addActionListener(this);
		
		addInputLine(jbOk, jbCancel, GridBagConstraints.EAST);
		
		pack();
	}
	

}


