package java.de.TimeSlice;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.*;

/**
 * @author      Burghard Grueter
 * @author      Johannes Schick
 * @version     1.0, 11/06/2000
 * @since       JDK1.2
 */
	/**
	 * class <pre>TaskPanel</pre> is one of the
	 * main processing classes. It manages the
	 * existing tasks and the active task. It is
	 * called to update periodically by the Timer
	 * by implementing <pre>TimerListener</pre>
	 * Changes due to user-interaction with the GUI
	 * are notified trough <pre>ControlPanelListener</pre>
	 */
	 
public class TaskPanel extends JPanel implements ActionListener, UpdateTaskListener 
{	
	private final String sActivate = "Start";
	private final String sDeactivate = "Stop";
	private final String sEdit = "Edit";
	
	ControlPanelListener tmlTasks;
	TaskData tData;
	TaskDialog tDialog;
	
	JProgressBar jpbRest;	
    JButton jbDelete;
    JButton jbActivate;
    JButton jbEdit;
	
	JLabel jlTaskName;
    JLabel jlRestdauerWert;
    JLabel jlPeriodeWert;
	


	/**
	 * 
	 *
	 * @param   tmlTasks    needed to tell the TaskManager about changes
	 *	
	 * @param   t  			TaskData provides <pre>TaskPanel</pre> with the data
	 *						needed to draw a panel representing the associated task
	 * @param   tDialog  	is called when the Edit-Button is pushed
	 */
    public TaskPanel(ControlPanelListener tmlTasks, TaskData t, TaskDialog tDialog) 
	{
        super();
		this.tmlTasks = tmlTasks;
		this.tData = t;
		this.tDialog = tDialog;
		buildGUI();
    }
	


	/**
	 * here all important actions are processed.
	 *
	 * @param   e  
	 */
    public void actionPerformed(ActionEvent e)
    {
		if (e.getSource()==jbDelete) 
		{		
			tmlTasks.deleteTask(tData.getTaskName());
			JPanel p = (JPanel) getParent();
			p.remove(this);
			p.update(p.getGraphics());
		}
		 else // Activate-Button pushed..
			if (e.getSource()==jbActivate) 
			{  
				if (jbActivate.getText().equals(sActivate)) 
				{
					tmlTasks.activateTask(true, jlTaskName.getText());
				    jbActivate.setText(sDeactivate);
				} 
				else
				{
					tmlTasks.activateTask(false, jlTaskName.getText());
				    jbActivate.setText(sActivate);				
				}	
			} 
			else // Edit Button is pushed...
			{			
				// getData from the dialog...
				Task h = tDialog.getTaskData(tData.getTaskName(), 
													Long.toString(tData.getDauer()), 
													Long.toString(tData.getPeriode()));
				if (h!=null) // Got Any?		
				try
				{
  					tmlTasks.editTask(tData.getTaskName(), h);
				}
				catch (TaskNameAlreadyExist tnae)
				{
				
				}		
			}
			
    }
	

	/**
	 * computs the current values of
	 * the fields <pre>jlRestdauer</pre> and <pre>jlPeriodeWert</pre>
	 * and sets them
	 */
	private void setStatus()
	{	
		jlRestdauerWert.setText((new java.sql.Time(tData.getRestdauer()-TaskTimer.HOUR)).toString());
		long day = (new Date()).getTime()-tData.getStart();
		day = (new Date(day)).getDate();
		jlPeriodeWert.setText(Long.toString(day)+"/"+Long.toString(tData.getPeriode()/TaskTimer.DAY));	
	}

	// each time, the data in the underlying 'Task'-instance is update, this
	// method gets a call	
	public void updateTaskPanel()
	{
	   jlTaskName.setText(tData.getTaskName());
	   setStatus();
	   // update Progressbar
	   jpbRest.setValue((int) (tData.getRestdauer()*100/tData.getDauer()));
	   
	   if (tData.isActive()) 
	   {
	   	  jbActivate.setText(sDeactivate);
		  jlTaskName.setForeground(Color.red);
	   }	 
	   else
	   {
	   	  jbActivate.setText(sActivate);
		  jlTaskName.setForeground(Color.black);	
	   }
	   try // sometimes this method is called though it is already destroyed
	   	   // but the Garbage Collector hasn't cleaned up everything yet.
	   {
		  update(getGraphics());
	   } catch(Exception e)
	   {
	   };		
	}
	
// GUI-building routines, not very interesting, quick&dirty anyhow	
	private JPanel getButtonPanel(){
	
		GridBagLayout gridbag = new GridBagLayout();
		GridBagConstraints c = new GridBagConstraints();
		
		c.anchor = GridBagConstraints.CENTER;
		c.insets = new Insets(4,4,4,4);
		
		JPanel h = new JPanel();
		h.setLayout(gridbag);
		
        jbActivate=new JButton(sActivate);
		Font f = jbActivate.getFont();
		f = new Font(f.getName(), f.getStyle(), f.getSize()-2);
		jbActivate.setFont(f);
		jbActivate.addActionListener(this);
		gridbag.setConstraints(jbActivate, c);
		h.add(jbActivate);	
		
        jbEdit=new JButton(sEdit);		
		jbEdit.setFont(f);
		jbEdit.addActionListener(this);
		gridbag.setConstraints(jbEdit, c);
		h.add(jbEdit);
		
		return h;
	
	}
	
	private void buildGUI()
	{		
		GridBagLayout gridbag = new GridBagLayout();		
		GridBagConstraints c = new GridBagConstraints();
		
		Insets a = new Insets(4,2,4,2);
		c.insets = a;
		
        setLayout(gridbag);
		setBorder(BorderFactory.createEtchedBorder());        
		
		c.gridwidth = GridBagConstraints.RELATIVE;		
		
		jlTaskName = new JLabel(tData.getTaskName());
		Font f = jlTaskName.getFont();
		jlTaskName.setFont(new Font(f.getName(), Font.BOLD, f.getSize()));
		jlTaskName.setForeground(Color.black);		
		gridbag.setConstraints(jlTaskName, c);
		add(jlTaskName);
		
		c.gridwidth = GridBagConstraints.REMAINDER;
		c.anchor = GridBagConstraints.EAST;
        jbDelete=new JButton("x");		
		jbDelete.addActionListener(this);
		gridbag.setConstraints(jbDelete, c);		
		add(jbDelete);
				
		c.anchor = GridBagConstraints.CENTER;
		JPanel h = getButtonPanel();	
		gridbag.setConstraints(h, c);
		add(h);				
			
		c.insets = new Insets(8,4,8,4);
		
		jpbRest = new JProgressBar(0,100);
		jpbRest.setValue(100);
		gridbag.setConstraints(jpbRest, c);
		add(jpbRest);
		
		c.insets = a;
		c.anchor = GridBagConstraints.CENTER;
		c.gridwidth = 1;
				
        JLabel jlRestdauer=new JLabel("Rest");
		gridbag.setConstraints(jlRestdauer, c);
		add(jlRestdauer);
				
        jlRestdauerWert=new JLabel();
		jlPeriodeWert=new JLabel();
		setStatus();
		
        gridbag.setConstraints(jlRestdauerWert,c);		
		add(jlRestdauerWert);
		
        JLabel jlPeriode=new JLabel("   Periode");
        gridbag.setConstraints(jlPeriode, c);
		add(jlPeriode);	
								
        gridbag.setConstraints(jlPeriodeWert, c);
		add(jlPeriodeWert);
		
	}
	
}


